@@ -1,6 +1,7 @@
 import numpy as np
 import pytest
 
+from pandas.compat import np_version_under1p21
 import pandas.util._test_decorators as td
 
 import pandas as pd
@@ -30,10 +31,11 @@ class BaseCastingTests(BaseExtensionTests):
         assert isinstance(result._mgr.arrays[0], np.ndarray)
         assert result._mgr.arrays[0].dtype == np.dtype(object)
 
-        # FIXME: these currently fail; dont leave commented-out
-        # check that we can compare the dtypes
-        # cmp = result.dtypes.equals(df.dtypes)
-        # assert not cmp.any()
+        # earlier numpy raises TypeError on e.g. np.dtype(np.int64) == "Int64"
+        if not np_version_under1p21:
+            # check that we can compare the dtypes
+            comp = result.dtypes == df.dtypes
+            assert not comp.any()
 
     def test_tolist(self, data):
         result = pd.Series(data).tolist()
